module.exports = defineTest({
	description: 'keeps accesses to computed properties if their key is reassigned'
});
